How to create a new theme
=========================

It's possible to create custom Theme for MySmile.


.. todo::

   #. Write a step-by-step creation of a new theme for example any `free template <http://w3layouts.com/free-responsive-html5-css3-website-templates/>`_
